NAME='puppet-dashboard-baseline'
PWD=`pwd`.strip!
SPEC_FILE="ext/redhat/#{NAME}.spec"
RPM_DEFINES = " --define \"_specdir #{PWD}/SPECS\" --define \"_rpmdir #{PWD}/RPMS\" --define \"_sourcedir #{PWD}/SOURCES\" --define \" _srcrpmdir #{PWD}/SRPMS\" --define \"_builddir #{PWD}/BUILD\""

task :default => :tarball do
end

task :clean do
  sh "rm -rf BUILD SOURCES SPECS SRPMS RPMS *.rpm *.tar.gz  *.tgz *.deb"
end

task :rpmcheck  do
  sh " [ -f /usr/bin/rpmbuild ] "
end

task :dirs do
  version=`git describe`.strip!
  dirs = [ 'BUILD', 'SPECS', 'SOURCES', 'RPMS', 'SRPMS' ]
  dirs.each do |d|
    FileUtils.mkdir_p "#{PWD}//#{d}"
  end
  sh "mv *.tar.gz SOURCES"
  sh "cp #{SPEC_FILE} SPECS"
  sh "sed -i \"s/VERSION/#{version}/g\" SPECS/#{NAME}.spec"
end

desc "Create a tarball for inclusion in packages"
task :tarball => :clean do
  version=`git describe`.strip!
  project=NAME
  puts "Tarball is #{project}-#{version}.tar.gz"
  if PWD =~ /tasks/ 
     path = "../"
  else
     path = ''
  end
  sh "mkdir -p /tmp/#{project}-#{version}/"
  sh "rsync -ax #{path}* /tmp/#{project}-#{version}/"
  sh "tar -C /tmp -p -c -z --exclude=.gz  -f /tmp/#{project}-#{version}.tar.gz #{project}-#{version}"
  sh "mv /tmp/#{project}-#{version}.tar.gz . "
  sh "rm -rf  /tmp/#{NAME}-#{version}"
end

# This package is RHEL6 or higher, so no worries on old payload signing
desc "Create a SRPM"
task :srpm => [ :rpmcheck, :tarball , :dirs ] do
  version=`git describe`.strip!
  sh "rpmbuild #{RPM_DEFINES} -bs SPECS/#{NAME}.spec"
  sh "mv -f SRPMS/* ."
  sh "rm -rf BUILD SRPMS RPMS SPECS SOURCES /tmp/#{NAME}-#{version}"
  
end

